@@ -1,12 +1,14 @@
 """ Core exporters apps config
 """
+import sys
+
 from django.apps import AppConfig
 
 import core_exporters_app.components.exporter.watch as exporter_watch
 from core_exporters_app.exporters import discover
 
 
-# TODO: loaded two times (not a problem and may not happen in production) 
+# TODO: loaded two times (not a problem and may not happen in production)
 # see http://stackoverflow.com/a/16111968 
 class CoreExportersAppConfig(AppConfig):
     """ Exporters configuration
@@ -17,5 +19,6 @@ class CoreExportersAppConfig(AppConfig):
     def ready(self):
         """ Run once at startup
         """
-        discover.discover_exporter()
-        exporter_watch.init()
+        if 'migrate' not in sys.argv:
+            discover.discover_exporter()
+            exporter_watch.init()
